match_std_type

Function match_std_type 

fn match_std_type<'tcx>(tcx: TyCtxt<'tcx>, type_ident: &str) -> Option<Ty<'tcx>>
Match a short type name against std types resolved by name-scan (no lang/diagnostic item), e.g. std::ascii::Char (AsciiChar) whose Char short name otherwise collides with the primitive char.