pub fn get_struct_self_ty<'tcx>(
tcx: TyCtxt<'tcx>,
def_id: DefId,
) -> Option<Ty<'tcx>>Expand description
Return the resolved self type for a method whose DefId points to an
associated item that lives inside an impl block returning an ADT.